@@ -1,15 +1,14 @@
 # -*- encoding:utf-8 -*-
-from __future__ import division, absolute_import, print_function
-
 from collections import namedtuple
+from copy import deepcopy
 import re
-import sys
 import textwrap
 import warnings
 
 import jinja2
 
 from numpydoc.numpydoc import update_config
+from numpydoc.xref import DEFAULT_LINKS
 from numpydoc.docscrape import (
     NumpyDocString,
     FunctionDoc,
@@ -22,12 +21,6 @@ from pytest import raises as assert_raises
 from pytest import warns as assert_warns
 
 
-if sys.version_info[0] >= 3:
-    sixu = lambda s: s
-else:
-    sixu = lambda s: unicode(s, 'unicode_escape')
-
-
 doc_txt = '''\
   numpy.multivariate_normal(mean, cov, shape=None, spam=None)
 
@@ -123,13 +116,13 @@ doc_txt = '''\
   >>> mean = (1,2)
   >>> cov = [[1,0],[1,0]]
   >>> x = multivariate_normal(mean,cov,(3,3))
-  >>> print x.shape
+  >>> print(x.shape)
   (3, 3, 2)
 
   The following is probably true, given that 0.6 is roughly twice the
   standard deviation:
 
-  >>> print list( (x[0,0,:] - mean) < 0.6 )
+  >>> print(list((x[0, 0, :] - mean) < 0.6))
   [True, True]
 
   .. index:: random
@@ -270,26 +263,6 @@ b : int
     assert_raises(ValueError, NumpyDocString, doc_text)
 
 
-def test_returnyield():
-    doc_text = """
-Test having returns and yields.
-
-Returns
--------
-int
-    The number of apples.
-
-Yields
-------
-a : int
-    The number of apples.
-b : int
-    The number of bananas.
-
-"""
-    assert_raises(ValueError, NumpyDocString, doc_text)
-
-
 def test_section_twice():
     doc_text = """
 Test having a section Notes twice
@@ -305,7 +278,7 @@ That should break...
     assert_raises(ValueError, NumpyDocString, doc_text)
 
     # if we have a numpydoc object, we know where the error came from
-    class Dummy(object):
+    class Dummy:
         """
         Dummy class.
 
@@ -495,13 +468,13 @@ Examples
 >>> mean = (1,2)
 >>> cov = [[1,0],[1,0]]
 >>> x = multivariate_normal(mean,cov,(3,3))
->>> print x.shape
+>>> print(x.shape)
 (3, 3, 2)
 
 The following is probably true, given that 0.6 is roughly twice the
 standard deviation:
 
->>> print list( (x[0,0,:] - mean) < 0.6 )
+>>> print(list((x[0, 0, :] - mean) < 0.6))
 [True, True]
 
 .. index:: random
@@ -666,13 +639,13 @@ definite.
 >>> mean = (1,2)
 >>> cov = [[1,0],[1,0]]
 >>> x = multivariate_normal(mean,cov,(3,3))
->>> print x.shape
+>>> print(x.shape)
 (3, 3, 2)
 
 The following is probably true, given that 0.6 is roughly twice the
 standard deviation:
 
->>> print list( (x[0,0,:] - mean) < 0.6 )
+>>> print(list((x[0, 0, :] - mean) < 0.6))
 [True, True]
 """)
 
@@ -726,7 +699,7 @@ def test_escape_stars():
         pass
 
     fdoc = FunctionDoc(func=my_func)
-    assert fdoc['Signature'] == r'my_func(a, b, \*\*kwargs)'
+    assert fdoc['Signature'] == ''
 
 
 doc4 = NumpyDocString(
@@ -844,7 +817,7 @@ def test_see_also_parse_error():
 
 
 def test_see_also_print():
-    class Dummy(object):
+    class Dummy:
         """
         See Also
         --------
@@ -855,8 +828,7 @@ def test_see_also_print():
         """
         pass
 
-    obj = Dummy()
-    s = str(FunctionDoc(obj, role='func'))
+    s = str(FunctionDoc(Dummy, role='func'))
     assert(':func:`func_a`, :func:`func_b`' in s)
     assert('    some relationship' in s)
     assert(':func:`func_d`' in s)
@@ -865,7 +837,7 @@ def test_see_also_print():
 def test_see_also_trailing_comma_warning():
     warnings.filterwarnings('error')
     with assert_warns(Warning, match='Unexpected comma or period after function list at index 43 of line .*'):
-        doc6 = NumpyDocString(
+        NumpyDocString(
             """
             z(x,theta)
 
@@ -886,7 +858,7 @@ Mope
 This should be ignored and warned about
 """
 
-    class BadSection(object):
+    class BadSection:
         """Class with bad section.
 
         Nope
@@ -1023,7 +995,7 @@ def test_use_blockquotes():
 
 def test_class_members():
 
-    class Dummy(object):
+    class Dummy:
         """
         Dummy class.
 
@@ -1039,7 +1011,7 @@ def test_class_members():
             """Spammity index"""
             return 0.95
 
-        class Ignorable(object):
+        class Ignorable:
             """local class, to be ignored"""
             pass
 
@@ -1355,7 +1327,7 @@ def test_templated_sections():
 def test_nonstandard_property():
     # test discovery of a property that does not satisfy isinstace(.., property)
 
-    class SpecialProperty(object):
+    class SpecialProperty:
 
         def __init__(self, axis=0, doc=""):
             self.axis = axis
@@ -1485,8 +1457,16 @@ def test_xref():
     xref_aliases = {
         'sequence': ':obj:`python:sequence`',
     }
-    config = namedtuple('numpydoc_xref_aliases',
-                        'numpydoc_xref_aliases')(xref_aliases)
+
+    class Config():
+        def __init__(self, a, b):
+            self.numpydoc_xref_aliases = a
+            self.numpydoc_xref_aliases_complete = b
+
+    xref_aliases_complete = deepcopy(DEFAULT_LINKS)
+    for key in xref_aliases:
+        xref_aliases_complete[key] = xref_aliases[key]
+    config = Config(xref_aliases, xref_aliases_complete)
     app = namedtuple('config', 'config')(config)
     update_config(app)
 
@@ -1496,7 +1476,7 @@ def test_xref():
         xref_doc_txt,
         config=dict(
             xref_param_type=True,
-            xref_aliases=xref_aliases,
+            xref_aliases=xref_aliases_complete,
             xref_ignore=xref_ignore
         )
     )
